==> TornAPIWrapper-1.0.1.tar.gz: TornAPIWrapper-1.0.1/README.md <==
![Some Weird Image](https://github.com/cxdzc/TornAPIWrapper/assets/110936008/271aa9c8-280e-4fd9-be9e-cd8b88d53329)

# 📦 TornAPIWrapper v1.0.0
A Python wrapper for the [Torn City API](https://www.torn.com/api.html), providing access to [Torn City](https://www.torn.com) data.

# 📠 Instructions
1. Install the TornAPIWrapper package by typing `pip tornapiwrapper` in your CMD.
2. Check out [examples](Examples) and [documentations](#-documentations) to familiarize yourself with the API.
3. Create an [API key](https://www.torn.com/preferences.php#tab=api).
4. Start programming!

# 📑 Documentations
There are two Torn City API documentations that I recommend reading to understand how the API works.

- **[Official Torn API Docs](https://www.torn.com/api.html):** This is the official Torn City API documentation, that is not properly documented. I only recommend this as it is official documentation.
<br><br>
- **[Unofficial Torn API Docs](https://tornapi.tornplayground.eu):** This is the unofficial Torn City API documentation, that is well documented and has an active and open-source [repository](https://github.com/Torn-Playground/tornapi-documentation).

# 💝 Contributors
<a href="https://github.com/cxdzc/tornapiwrapper/graphs/contributors">
  <img width="75" src="https://contrib.rocks/image?repo=cxdzc/tornapiwrapper"/>
</a>

# 💌 Support
Love open-source projects? Find the project helpful or fun? Support sustainability here, your contribution keeps innovation and fun alive.

<a rel="license" href="https://www.buymeacoffee.com/cxdzc"><img width="200" alt="bmc-button" src="https://github.com/cxdzc/TornAPIWrapper/assets/110936008/494a782f-e327-4d07-8821-e962f03842e4"></a>

# 📜 License
> [!NOTE]
> This is not legal advice.

The content and software in this GitHub repository are licensed under the [MIT License](LICENSE). A short and simple permissive license with conditions only requiring preservation of copyright and license notices. Licensed works, modifications, and larger works may be distributed under different terms and without source code.

<a rel="license" href="LICENSE"><img alt="MIT License" src="https://img.shields.io/badge/License-MIT-ab1436"/></a>

# 🔗 Links
These are links that may help with your programming.

- [List of Torn City item IDs](https://www.tornstats.com/items)

==> TornAPIWrapper-1.0.2.tar.gz: TornAPIWrapper-1.0.2/README.md <==
![Some Weird Image](https://github.com/cxdzc/TornAPIWrapper/assets/110936008/271aa9c8-280e-4fd9-be9e-cd8b88d53329)

# 📦 TornAPIWrapper v1.0.2
A Python wrapper for the [Torn City API](https://www.torn.com/api.html), providing access to [Torn City](https://www.torn.com) data.

# 📠 Instructions
1. Install the [TornAPIWrapper](https://pypi.org/project/TornAPIWrapper) package by typing `pip install tornapiwrapper` in your CMD.
2. Check out [examples](https://github.com/cxdzc/TornAPIWrapper/tree/main/Examples) and [documentations](https://github.com/cxdzc/TornAPIWrapper#-documentations) to familiarize yourself with the API.
3. Create an [API key](https://www.torn.com/preferences.php#tab=api).
4. Start programming!

# 📑 Documentations
There are two Torn City API documentations that I recommend reading to understand how the API works.

- **[Official Torn API Docs](https://www.torn.com/api.html):** This is the official Torn City API documentation, that is not properly documented. I only recommend this as it is official documentation.
<br><br>
- **[Unofficial Torn API Docs](https://tornapi.tornplayground.eu):** This is the unofficial Torn City API documentation, that is well documented and has an active and open-source [repository](https://github.com/Torn-Playground/tornapi-documentation).

# 💝 Contributors
<a href="https://github.com/cxdzc/tornapiwrapper/graphs/contributors">
  <img width="75" src="https://contrib.rocks/image?repo=cxdzc/tornapiwrapper"/>
</a>

# 💌 Support
Love open-source projects? Find the project helpful or fun? Support sustainability here, your contribution keeps innovation and fun alive.

<a rel="license" href="https://www.buymeacoffee.com/cxdzc"><img width="200" alt="bmc-button" src="https://github.com/cxdzc/TornAPIWrapper/assets/110936008/494a782f-e327-4d07-8821-e962f03842e4"></a>

# 📜 License
> [!NOTE]
> This is not legal advice.

The content and software in this GitHub repository are licensed under the [MIT License](https://github.com/cxdzc/TornAPIWrapper/blob/main/LICENSE). A short and simple permissive license with conditions only requiring preservation of copyright and license notices. Licensed works, modifications, and larger works may be distributed under different terms and without source code.

<a rel="license" href="LICENSE"><img alt="MIT License" src="https://img.shields.io/badge/License-MIT-ab1436"/></a>

# 🔗 Links
These are links that may help with your programming.

- [List of Torn City item IDs](https://www.tornstats.com/items)
